@@ -23,10 +23,11 @@ class ExpSuffix(mtext.Text):
         )
 
 
-def _exp_text(
+def exp_text(
     exp="",
     text="",
     loc=0,
+    *,
     ax=None,
     fontname=None,
     fontsize=None,
@@ -78,16 +79,16 @@ def _exp_text(
         1: {"xy": (0.05, 0.9550 - pad), "va": "bottom"},
         2: {"xy": (0.05, 0.9450 - pad), "va": "top"},
         3: {"xy": (0.05, 0.95 - pad), "va": "top"},
+        4: {"xy": (0.05, 0.9550 - pad), "va": "bottom"},
     }
 
-    if loc not in [0, 1, 2, 3]:
+    if loc not in [0, 1, 2, 3, 4]:
         raise ValueError(
             "loc must be in {0, 1, 2}:\n"
             "0 : Above axes, left aligned\n"
             "1 : Top left corner\n"
             "2 : Top left corner, multiline\n"
-            "3 : Split EXP above axes, rest of label in"
-            "top left corner"
+            "3 : Split EXP above axes, rest of label in top left corner\n"
         )
 
     def pixel_to_axis(extent, ax=None):
@@ -126,7 +127,6 @@ def _exp_text(
 
     exptext = ExpText(
         *loc1_dict[_exp_loc]["xy"],
-        # s=exp,
         text=exp,
         transform=ax.transAxes,
         ha="left",
@@ -134,7 +134,7 @@ def _exp_text(
         fontsize=_font_size * 1.3,
         fontweight="bold",
         fontstyle="italic" if italic[0] else "normal",
-        fontname=fontname
+        fontname=fontname,
     )
     ax._add_text(exptext)
 
@@ -145,7 +145,7 @@ def _exp_text(
         _t = mtransforms.offset_copy(
             exptext._transform, x=_exp_xoffset, units="inches", fig=ax.figure
         )
-    elif loc == 1:
+    elif loc in [1, 4]:
         _t = mtransforms.offset_copy(
             exptext._transform,
             x=_exp_xoffset,
@@ -171,7 +171,7 @@ def _exp_text(
         va=loc2_dict[loc]["va"],
         fontsize=_font_size,
         fontname=fontname,
-        fontstyle="italic" if italic[1] else "normal"
+        fontstyle="italic" if italic[1] else "normal",
     )
     ax._add_text(expsuffix)
 
@@ -221,9 +221,10 @@ def lumitext(text="", ax=None, fontname=None, fontsize=None):
 
 
 # Wrapper
-def _exp_label(
-    ax=None,
+def exp_label(
+    exp="",
     loc=0,
+    *,
     data=False,
     paper=False,
     supplementary=False,
@@ -234,19 +235,20 @@ def _exp_label(
     fontname=None,
     fontsize=None,
     pad=0,
-    exp="",
     italic=(False, False),
+    ax=None,
 ):
     """A convenience wrapper combining ``<exp>.text`` and ``lumitext`` providing for
     the most common use cases.
     Parameters
     ----------
         loc : int, optional
-            Label positon of ``_exp_text`` label:
+            Label positon of ``exp_text`` label:
             - 0 : Above axes, left aligned
             - 1 : Top left corner
             - 2 : Top left corner, multiline
             - 3 : Split EXP above axes, rest of label in top left corner"
+            - 4 : (1) Top left corner, but align "rlabel" underneath
         ax : matplotlib.axes.Axes, optional
             Axes object (if None, last one is fetched)
         data : bool, optional
@@ -280,6 +282,9 @@ def _exp_label(
             A matplotlib `Axes <https://matplotlib.org/3.1.1/api/axes_api.html>`_ object
     """
 
+    if ax is None:
+        ax = plt.gca()
+
     # Right label
     if rlabel is not None:
         _lumi = rlabel
@@ -292,7 +297,8 @@ def _exp_label(
         else:
             _lumi = "{} (13 TeV)".format(str(year) if year is not None else "")
 
-    lumitext(text=_lumi, ax=ax, fontname=fontname, fontsize=fontsize)
+    if loc < 4:
+        lumitext(text=_lumi, ax=ax, fontname=fontname, fontsize=fontsize)
 
     # Left label
     if llabel is not None:
@@ -308,7 +314,7 @@ def _exp_label(
 
         _label = " ".join(_label.split())
 
-    exp = _exp_text(
+    exptext, expsuffix = exp_text(
         exp=exp,
         text=_label,
         loc=loc,
@@ -318,5 +324,25 @@ def _exp_label(
         italic=italic,
         pad=pad,
     )
+    if loc == 4:
+        _t = mtransforms.offset_copy(
+            exptext._transform,
+            y=-exptext.get_window_extent().height / ax.figure.dpi,
+            units="inches",
+            fig=ax.figure,
+        )
+        _lumi = r"$\sqrt{s} = \mathrm{13\ TeV}, " + str(lumi) + r"\ \mathrm{fb}^{-1}$"
+        explumi = ExpSuffix(
+            *exptext.get_position(),
+            text=rlabel if rlabel is not None else _lumi,
+            transform=_t,
+            ha=exptext.get_ha(),
+            va="top",
+            fontsize=fontsize,
+            fontname=fontname,
+            fontstyle="normal",
+        )
+        ax._add_text(explumi)
+        return exptext, expsuffix, explumi
 
-    return exp
+    return exptext, expsuffix
